%global upstream_name ase

Name:			python-ase
Version:		3.22.1
Release:        1%{?dist}
Summary:		Atomic Simulation Environment

License:		LGPLv2+ and MIT

URL:			https://wiki.fysik.dtu.dk/ase/
Source0:		https://gitlab.com/%{upstream_name}/%{upstream_name}/-/archive/%{version}/%{upstream_name}-%{version}.tar.gz

BuildArch:		noarch

BuildRequires:		gettext
BuildRequires:		desktop-file-utils

BuildRequires:		python3-devel
BuildRequires:		python3-numpy
BuildRequires:		python3-pytest
BuildRequires:		python3-pytest-mock
BuildRequires:		python3-scipy
BuildRequires:		python3-setuptools
BuildRequires:		python3-tkinter

Requires:		python3-matplotlib
Requires:		python3-netcdf4
Requires:		python3-numpy
Requires:		python3-scipy
Requires:		python3-spglib
Requires:		python3-tkinter

%global _description\
The Atomic Simulation Environment (ASE) is the common part of the simulation\
tools developed at CAMd. ASE provides Python modules for manipulating atoms,\
analyzing simulations, visualization etc.

%description %_description

%package -n python3-ase
Summary:		Atomic Simulation Environment for Python 3

%description -n python3-ase
The Atomic Simulation Environment (ASE) is the common part of the simulation
tools developed at CAMd. ASE provides Python 3 modules for manipulating atoms,
analyzing simulations, etc.

%prep
%setup -qn %{upstream_name}-%{version}

rm -f ase/test/constraints/test_fixinternals.py

rm -f ase/test/calculator/dftb/test_dftb_bandstructure.py
rm -f ase/test/calculator/openmx/test_md.py
rm -f ase/test/calculator/openmx/test_version.py
rm -f ase/test/fio/test_openmx.py

rm -f ase/test/test_units.py

sed -i 's/importlib.find_loader/importlib.util.find_spec/' ase/test/testsuite.py
sed -i 's/importlib.find_loader/importlib.util.find_spec/' ase/calculators/autodetect.py

cp -p doc/static/%{upstream_name}256.png %{upstream_name}.png
cp -p doc/%{upstream_name}-gui.desktop %{upstream_name}-gui.desktop
rm -rf doc

find . -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'

%build
%{__python3} setup.py build


%install

%{__python3} setup.py install --skip-build --prefix=%{_prefix} \
	   --optimize=1 --root %{buildroot}


mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install \
--dir %{buildroot}%{_datadir}/applications \
%{upstream_name}-gui.desktop

mkdir -p %{buildroot}%{_datadir}/pixmaps
install -p -m 644 %{upstream_name}.png %{buildroot}%{_datadir}/pixmaps

mkdir %{buildroot}%{python3_sitelib}/%{upstream_name}/gui/share
cp -rp %{buildroot}%{python3_sitelib}/%{upstream_name}/gui/po %{buildroot}%{python3_sitelib}/%{upstream_name}/gui/share/locale
%find_lang ag
rm -rf %{buildroot}%{python3_sitelib}/%{upstream_name}/gui/share
sed -i "s|share/locale|po|g" ag.lang

find %{buildroot}%{python3_sitelib}/%{upstream_name} -type d | xargs -I _file echo "%dir _file" > d3.list
find %{buildroot}%{python3_sitelib}/%{upstream_name} -type f ! -name "*.mo" > f3.list
cat ag.lang d3.list f3.list > files3.list
sed -i "s|%{buildroot}||g" files3.list


%check
export PYTHONPATH=`pwd`/build/lib
export PATH=`pwd`/bin:${PATH}  # the tests assume Python 3 scripts are named the same as Python 2 scripts
ln -s `which python3` `pwd`/bin/python
LC_ALL=C.UTF-8 python -m ase test --verbose --pytest -W ignore -W 'once::DeprecationWarning'
cd -


%files -n python3-ase -f files3.list
%doc COPYING* LICENSE README*
%{_bindir}/ase*
%{_datadir}/applications/%{upstream_name}-gui.desktop
%{_datadir}/pixmaps/%{upstream_name}.png
%{python3_sitelib}/*.egg-info


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.22.1-1
- initial build
